@@ -10,7 +10,7 @@ class ConnectionInfo:
     """
 
     def __init__(self, dialect, host, port, password, user=None, db_name=None, name=None, params=None, min_size=3,
-                 max_size=10, enable=True):
+                 max_size=10, enable=True, async_enable=True):
         # 数据库dialect类型
         self.dialect = dialect
         # 连接池名称
@@ -36,3 +36,5 @@ class ConnectionInfo:
         self.max_size = max_size
         # 是否启用
         self.enable = enable
+        # 是否启用异步
+        self.async_enable = async_enable
