@@ -51,9 +51,12 @@ class InitConnectionPool:
         :param conn_info: 连接信息
         :return: AsyncConnectionPool
         """
-        from psycopg_pool import AsyncConnectionPool
-        conn_info_string = f"postgresql://{conn_info.user}:{conn_info.password}@{conn_info.host}:{conn_info.port}/{conn_info.db_name}"
-        return AsyncConnectionPool(conn_info_string)
+        if conn_info.async_enable:
+            from psycopg_pool import AsyncConnectionPool
+            conn_info_string = f"postgresql://{conn_info.user}:{conn_info.password}@{conn_info.host}:{conn_info.port}/{conn_info.db_name}"
+            return AsyncConnectionPool(conn_info_string)
+        else:
+            raise NotImplementedError
 
     @staticmethod
     async def create_pool_mysql(conn_info: ConnectionInfo):
@@ -62,12 +65,15 @@ class InitConnectionPool:
         :param conn_info: 连接信息
         :return:
         """
-        import aiomysql
-        pool = await aiomysql.create_pool(host=conn_info.host, port=conn_info.port, user=conn_info.user,
-                                          password=conn_info.password,
-                                          db=conn_info.db_name, autocommit=True, minsize=conn_info.min_size,
-                                          maxsize=conn_info.max_size)
-        return pool
+        if conn_info.async_enable:
+            import aiomysql
+            pool = await aiomysql.create_pool(host=conn_info.host, port=conn_info.port, user=conn_info.user,
+                                              password=conn_info.password,
+                                              db=conn_info.db_name, autocommit=True, minsize=conn_info.min_size,
+                                              maxsize=conn_info.max_size)
+            return pool
+        else:
+            raise NotImplementedError
 
     @staticmethod
     def create_pool_mongodb(conn_info: ConnectionInfo):
@@ -76,10 +82,13 @@ class InitConnectionPool:
         :param conn_info: 连接信息
         :return:
         """
-        import motor
-        conn_info_string = f"mongodb://{conn_info.user}:{conn_info.password}@{conn_info.host}:{conn_info.port}"
-        pool = motor.motor_tornado.MotorClient(conn_info_string)
-        return pool
+        if conn_info.async_enable:
+            import motor
+            conn_info_string = f"mongodb://{conn_info.user}:{conn_info.password}@{conn_info.host}:{conn_info.port}"
+            pool = motor.motor_tornado.MotorClient(conn_info_string)
+            return pool
+        else:
+            raise NotImplementedError
 
     @staticmethod
     async def create_pool_es(conn_info: ConnectionInfo):
@@ -88,9 +97,12 @@ class InitConnectionPool:
         :param conn_info: 连接信息
         :return:
         """
-        from elasticsearch import AsyncElasticsearch
-        host_str = conn_info.host.split(",")
-        hosts = [f"{conn_info.user}:{conn_info.password}@{host}:{conn_info.port}" for host in host_str]
-        pool = AsyncElasticsearch(hosts=hosts)
-        return pool
+        if conn_info.async_enable:
+            from elasticsearch import AsyncElasticsearch
+            host_str = conn_info.host.split(",")
+            hosts = [f"{conn_info.user}:{conn_info.password}@{host}:{conn_info.port}" for host in host_str]
+            pool = AsyncElasticsearch(hosts=hosts)
+            return pool
+        else:
+            raise NotImplementedError
 
