@@ -6,6 +6,7 @@
 
 import inspect
 import json
+from datetime import datetime
 from typing import Optional, Awaitable
 
 from bson import ObjectId
@@ -37,7 +38,7 @@ class BaseHandler(RequestHandler):
         重写父类get请求处理方法，直接调用post方法统一处理
         :return:
         """
-        await self.post()
+        await self.request_handler()
 
     async def post(self):
         """
@@ -46,6 +47,18 @@ class BaseHandler(RequestHandler):
         通过不同的url指向不同处理方法
         :return:
         """
+        await self.request_handler()
+
+    async def options(self):
+        """
+        解决跨域验证请求
+        HTTP的204(No Content)响应, 就表示执行成功, 但是没有数据
+        :return:
+        """
+        self.set_status(204)
+        self.finish()
+
+    async def request_handler(self):
         # 通过url路径获取对应的处理方法
         res = [item for item in RouterMapping.instance().handlerMapping
                if item[0] == self.request.path]
@@ -80,6 +93,7 @@ class BaseHandler(RequestHandler):
                     if argument_value is None:
                         # 查看是否有默认值，如果有直接跳过即可
                         if parameter.default is not inspect.Parameter.empty:
+                            params_list.append(parameter.default)
                             continue
                         else:
                             # 如果没有有默认值，要抛出异常 提示"请求缺少必要参数"
@@ -92,8 +106,6 @@ class BaseHandler(RequestHandler):
                             parameter_type = type(parameter.default)
                         else:
                             parameter_type = type(parameter.default)
-                    # new_value = parse_val(argument_value, parameter_type)
-                    # params_list.append(new_value)
                     # # 获取实参类型
                     # argument_type = type(argument_value)
                     if isinstance(argument_value, list):  # 如果参数是集合类型要进行遍历并进行转码
@@ -102,23 +114,6 @@ class BaseHandler(RequestHandler):
                             params_list.append(parse_val(argument_value[0], parameter_type))
                         else:  # 多个要使用集合存入
                             params_list.append([parse_val(v, parameter_type) for v in argument_value])
-                    # print(f"parameter_name:{parameter_name},parameter_type:{parameter_type},argument_type:{argument_type}")
-                    # new_value = parse_val(argument_value,)
-                    # elif isinstance(argument_value, list):  # 如果参数是集合类型要进行遍历并进行转码
-                    #     # 仅一个 直接存入
-                    #     if len(argument_value) == 1:
-                    #         params_list.append(argument_value[0].decode())
-                    #     else:  # 多个要使用集合存入
-                    #         params_list.append([v.decode() for v in argument_value])
-                    # else:
-                    #     # 其他类型的直接存入
-                    #     params_list.append(argument_value)
-                    # val_type = type(args.get(func_params[i], None))
-                    # if func_params[i] in params.keys():
-                    #     val = params.get(func_params[i])
-                    #     if not is_json:
-                    #         val = parse_val(val, val_type)
-                    #     params_list.append(val)
 
             # 判断是否为异步非阻塞方法，true 则直接调用
             if inspect.iscoroutinefunction(handler_method):
@@ -126,7 +121,8 @@ class BaseHandler(RequestHandler):
             else:
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-            self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
+            if data:
+                self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
             raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
 
@@ -184,6 +180,8 @@ class JSONEncoder(json.JSONEncoder):
     def default(self, o):
         if isinstance(o, ObjectId):
             return str(o)
+        elif isinstance(o, datetime):
+            return str(o)
         return json.JSONEncoder.default(self, o)
 
 
