@@ -102,7 +102,7 @@ class WebServer:
         # 4、启动时创建数据库连接池
         tornado.ioloop.IOLoop.current().run_sync(InitConnectionPool.create_pool)
         # 5、自动化注册Handler处理类，
-        self.autoRegisterHandler(f"{os.path.dirname(sys.argv[0])}/{options.handler_path}", options.handler_path)
+        self.autoRegisterHandler(f"{os.path.abspath(os.path.dirname(sys.argv[0]))}/{options.handler_path}", options.handler_path)
         self.app = tornado.web.Application(
             RouterMapping.instance(),
             cookie_secret=options.cookie_secret,
@@ -134,6 +134,7 @@ class WebServer:
         :param pkg_name: 引入模块前缀
         """
         # 首先获取当前目录所有文件及文件夹
+        print(path)
         dynamic_handler_names = os.listdir(path)
         for handler_name in dynamic_handler_names:
             # 利用os.path.join()方法获取完整路径
